@@ -641,7 +641,7 @@ class TuringMachine():
             filename_=os.path.join(dirpath,f'{i}')
             g=self.save_img(filename_,q_c=q,q_prev=set([q_c for q_c,_,_,_ in q]),
                     symbols=symbols,states=states,status=status,
-                    dpi=dpi)
+                    dpi=dpi,format="png")
             q_prev=q
             im=Image.open(filename_+".png")
             width, height = im.size
@@ -650,7 +650,7 @@ class TuringMachine():
             i+=1
             filename_=os.path.join(dirpath,f'{i}')
             g=self.save_img(filename_,q_c=q,status=status,
-                        symbols=symbols,states=states,dpi=dpi)
+                        symbols=symbols,states=states,dpi=dpi,format="png")
             im=Image.open(filename_+".png")
             images.append(im)
             i+=1
