@@ -129,7 +129,7 @@ class FiniteAutomaton():
         if isinstance(res,set) or isinstance(res,list):
             return set([self._state(q) for q in res])
         else:
-            return self._state(res)
+            return set([self._state(res)])
 
 
     def items(self):
@@ -571,7 +571,7 @@ class FiniteAutomaton():
                 print(r,end="",file=f)
                 print("|",file=f)
 
-    def save_img(self,filename,q_c=set(),a_c=set(),q_prev=set(),symbols={},states={},format='svg',dpi="90.0",string=None):
+    def save_img(self,filename,q_c=set(),a_c=set(),q_prev=set(),symbols={},states={},format='svg',dpi="60.0",string=None):
         """ Saves machine as an image
 
         :param filename: Filename of image
@@ -581,7 +581,7 @@ class FiniteAutomaton():
         :param symbols: Replacements of the symbols to show (default is empty)
         :param states: Replacements of the states to show (default is empty)
         :param format: Format of image (default is svg)
-        :param dpi: Resolution of image (default is "90.0")
+        :param dpi: Resolution of image (default is "60.0")
         :param string: Label of string being analysed (default is None)
         :returns: None"""
         dot=self.graph(q_c=q_c,a_c=a_c,q_prev=q_prev,symbols=symbols,states=states,format=format,dpi=dpi,string=string)
