@@ -55,7 +55,7 @@ class NonDeterministicFiniteAutomaton_epsilon(FiniteAutomaton):
 
         :returns: Destination state"""
         try:
-            return self.get_transition(q,a)
+            return self.expansion_epsilon(self.get_transition(q,a))
         except DoesNotExistsTransition:
             return set()
 
