@@ -60,8 +60,10 @@ def ndfa2dfa(ndfa,rename=True,remove_sink=True):
                         new_state.update(ndfa.get_transition(q,a))
                     except DoesNotExistsTransition:
                         pass
+                if len(new_state)==0:
+                    continue
                 new_state_=codify_state(ndfa.Q,new_state)
-                dfa.add_transition(state_,a,new_state_,force=True)
+                dfa.add_transition(state_,a,set([new_state_]),force=True)
                 if not new_state_ in states:
                     new_new_states[new_state_]=new_state
                 if len(new_state.intersection(ndfa.A))>0:
@@ -85,10 +87,10 @@ def dfa2ndfa_e(dfa,rename=True,remove_sink=True):
         for na,nq_f in t_.items():
             na=na+1
             try:
-                ndfa_e.ttable[nq_i][na]=set([nq_f])
+                ndfa_e.ttable[nq_i][na]=set(nq_f)
             except KeyError:
                 ndfa_e.ttable[nq_i]={}
-                ndfa_e.ttable[nq_i][na]=set([nq_f])
+                ndfa_e.ttable[nq_i][na]=set(nq_f)
 
     ndfa_e.q_0=dfa.q_0
     ndfa_e.A=set(dfa.A)
